#import "template.typ": *

#set page(
  paper: "a6",
  margin: (x: 0.8cm, y: 0.8cm),
)
#set text(
  font: "MonaspiceNe NF",
  size: 4pt,
  fill: bodyColour
)
#set par(
  justify: true,
  leading: 0.52em,
)

#chunk((
  align(center)[
    #text(size: 10pt, weight: "bold", fill: textDarkOrange)[NICK HIEBERT]
  ],
  align(center)[
    #grid(
      columns: (auto, auto, auto),
      gutter: 1em,
      align: horizon,
      contact(
        prefix: "tel:",
        entry: "12049986746",
        display: "1-204-998-6746",
        icon: "assets/phone.svg"
      ),
      contact(
        prefix: "mailto:",
        entry: "nick@upRootNutrition.com",
        display: "nick@upRootNutrition.com",
        icon: "assets/email.svg"
      ),
      contact(
        prefix: "",
        entry: "https://gitlab.com/upRootNutrition",
        display: "gitlab.com/upRootNutrition",
        icon: "assets/gitlab.svg"
      )
    )
  ],
  divider("ABOUT ME"),
  text()[I studied Human Nutritional Science at the #cite("https://umanitoba.ca/", "University of Manitoba"). Nutrition is my foremost passion, but I’ve also acquired a diverse range of skills and interests over the years that I pursue with persistence and enthusiasm. My interest in programming began after switching from Windows to #cite("https://nixos.org", "NixOS"), which requires configuration in Nix, a purely functional programming language. Since then, I’ve taught myself #cite("https://elm-lang.org/", "Elm") and #cite("https://typst.app/", "Typst") and am now learning #cite("https://www.haskell.org/", "Haskell") for the development of the #cite("https://uprootnutrition.com/nutridex", "nutriDex") app.],
  divider("EXPERIENCE"),
  job(
      title: "upRootNutrition",
      position: "Content Creator, Programmer",
      date: "2018 - Present",
      lang: (
        "assets/uproot.jpg",
      ),
      details: (
        "Developed evidence-based content related to health and nutrition sciences.",
        "Conducted in-depth investigations into nutrition-related research questions for clients.",
        "Mentored clients on nutrition science research methodologies and interpretation.",
        [Managed a 2000+ member #cite("https://discord.gg/eeYQ2wJknS", "Discord") community for engagement and knowledge-sharing.],
        [Curated and maintained a 2000+ reference nutrition literature #cite("https://obsidian.md", "Obsidian") vault.]
      )
    ),
  divider("PROJECTS"),
  job(
    title: "upRootNutrition",
    entry: "https://source.uprootnutrition.com/upRootNutrition/website",
    lines: "35,650",
    position: "Lead Developer",
    date: "2024 - Present",
    lang: (
      "assets/elm.svg",
      "assets/typescript.svg",
      "assets/html.svg",
      "assets/css.svg",
      "assets/nix.svg",
      "assets/markdown.svg"
    ),
    description: [Developed the frontend for my online platform, #cite("https://upRootNutrition.com", "upRootNutrition"), primarily written in the Elm programming language, but also features TypeScript, CSS, and HTML. The project consists of a modular configuration for pages, styling, and data handling. Records, helper functions, and Markdown parsing are organized to make adding new content trivially easy. The project also makes use of a #cite("https://github.com/numtide/devshell", "Devshell") and #cite("https://github.com/direnv/direnv", "Direnv") to create a declarative and reproducible development environment.]
  ),
  job(
    title: "NixOS Dotfiles",
    entry: "https://source.uprootnutrition.com/upRootNutrition/dotfiles",
    lines: "20,903",
    position: "Lead Developer",
    date: "2022 - Present",
    lang: (
      "assets/nix.svg",
      "assets/bash.svg",
      "assets/css.svg",
      "assets/markdown.svg",
    ),
    description: [Built a modular, multi-system NixOS configuration using #cite("https://nixos.wiki/wiki/Flakes", "Flakes") and #cite("https://nixos.wiki/wiki/Home_Manager", "Home Manager"), and designed many records and helper functions to streamline system and user setups. There are structured and expandable modules for machines, services, theming, and user profiles. Secrets are securely managed via #cite("https://github.com/Mic92/sops-nix", "sops-nix") and a hardware dongle for private keys. Flake #cite("https://nixos-unified.org/templates.html", "Templates") are used for quick bootstrapping in languages like Haskell and Elm.]
  ),
  job(
    title: "This Resume",
    entry: "https://source.uprootnutrition.com/upRootNutrition/resume",
    position: "Lead Developer",
    date: "2025 - Present",
    lang: (
      "assets/typst.png",
      "assets/nix.svg"
    ),
    description: [Developed a customizable #cite("https://source.uprootnutrition.com/upRootNutrition/resume", "resume") template using Typst, a modern markup-based typesetting system with some functional programming features that encourages immutable state. The project features modular components for sections like education, work experience, and projects, with flexible styling options.],
  ),
  job(
    title: "Homelab",
    entry: "https://source.uprootnutrition.com/upRootNutrition/dotfiles/src/branch/main/modules/nixos/services",
    lines: "35,650",
    position: "Lead Developer",
    date: "2023 - Present",
    lang: (
      "assets/nix.svg",
    ),
    description: [
          Developed and built a custom, NixOS-based homelab for managing and hosting multiple services, such as
          #cite("https://github.com/dani-garcia/vaultwarden", "Vaultwarden"),
          #cite("https://codeberg.org/forgejo/forgejo", "Forgejo"),
          #cite("https://github.com/nextcloud/server", "Nextcloud"),
          #cite("https://github.com/jellyfin/jellyfin", "Jellyfin"),
          #cite("https://github.com/searxng/searxng", "SearXNG"),
          #cite("https://github.com/ollama/ollama", "Ollama"), as well as the
          #cite("https://uprootnutrition.com/", "upRootNutrition") website. The configuration features automated SSL certificate generation for HTTPS, and hosts services to the internet via reverse proxy with the #cite("https://caddyserver.com/", "Caddy") webserver. Currently, the homelab is a Ryzen 5 system with 32GB of RAM and 8TB of NAS storage.
        ]
  ),
  divider("PUBLICATIONS"),
  pub(
    author: "Moore, Jeff M., et al.",
    doi: "doi.org/10.1093/cdn/nzac043",
    entry: "https://doi.org/10.1093/cdn/nzac043",
    title: "‘Evidence for a Lean Mass Hyperresponder Phenotype Is Lacking with Increases in LDL Cholesterol of Clinical Significance in All Categories of Response to A-Restricted Diet’. Current Developments in Nutrition, vol. 6, no. 5, May 2022, p. nzac043."
  ),
  divider("EDUCATION"),
  list((
    edu(
      institute: "University of Manitoba",
      cert: "Human Nutritional Science",
      year: "2011"
    ),
    edu(
      institute: "Studio 11 Inc",
      cert: "Audio Production",
      year: "2008"
    )
  ))
))
